@@ -1,5 +1,6 @@
 # export class hierarchy
 from .path import AsyncPath, AsyncPurePath, AsyncWindowsPath, \
-  AsyncPosixPath, PureAsyncPosixPath, PureAsyncWindowsPath
+  AsyncPosixPath, AsyncPurePosixPath, AsyncPureWindowsPath
 
+# export iterable async file handle
 from .handle import IterableAIOFile
