@@ -1,23 +1,18 @@
 from __future__ import annotations
 from pathlib import PosixPath, WindowsPath, _NormalAccessor, \
   Path, PurePath, _ignore_error
-from typing import Optional, List, Union, AsyncIterable
-from os import stat_result
+from typing import AsyncIterable, Final
+from os import stat_result, PathLike
 from stat import S_ISDIR, S_ISLNK, S_ISREG, S_ISSOCK, S_ISBLK, \
   S_ISCHR, S_ISFIFO
 import os
 
-from aiofile import AIOFile
-from aiofiles import os as async_os
-from aiofiles.os import wrap as method_as_method_coro, \
-  wrap as func_as_corofunc
-
 from .selectors import _make_selector
 from .flavours import _async_windows_flavour, _async_posix_flavour
-from .wrap import coro_as_method_coro, func_as_method_coro, to_thread
-from .handle import IterableAIOFile, read_full_file
+from .wrap import to_async_method, to_thread, func_to_async_func
+from .handle import get_handle, Handle
 from .scandir import EntryWrapper, scandir_async
-from .types import Final, Literal, FileMode
+from .types import FileMode
 
 
 DEFAULT_ENCODING: Final[str] = 'utf-8'
@@ -25,37 +20,40 @@ ON_ERRORS: Final[str] = 'ignore'
 NEWLINE: Final[str] = '\n'
 
 
-getcwd = func_as_corofunc(os.getcwd)
-close = func_as_corofunc(os.close)
+Paths = Path | PathLike | str
+
+
+getcwd = os.getcwd
+close = func_to_async_func(os.close)
 
 
 class _AsyncAccessor(_NormalAccessor):
-  stat = coro_as_method_coro(async_os.stat)
-  lstat = func_as_method_coro(os.lstat)
-  open = func_as_method_coro(os.open)
-  listdir = func_as_method_coro(os.listdir)
-  chmod = func_as_method_coro(os.chmod)
+  stat = to_async_method(os.stat)
+  lstat = to_async_method(os.lstat)
+  open = to_async_method(os.open)
+  listdir = to_async_method(os.listdir)
+  chmod = to_async_method(os.chmod)
 
   if hasattr(_NormalAccessor, 'lchmod'):
-    lchmod = method_as_method_coro(_NormalAccessor.lchmod)
+    lchmod = to_async_method(_NormalAccessor.lchmod)
 
-  mkdir = coro_as_method_coro(async_os.mkdir)
-  unlink = func_as_method_coro(os.unlink)
+  mkdir = to_async_method(os.mkdir)
+  unlink = to_async_method(os.unlink)
 
   if hasattr(_NormalAccessor, 'link'):
-    link = method_as_method_coro(_NormalAccessor.link)
+    link = to_async_method(_NormalAccessor.link)
 
-  rmdir = coro_as_method_coro(async_os.rmdir)
-  rename = coro_as_method_coro(async_os.rename)
-  replace = func_as_method_coro(os.replace)
+  rmdir = to_async_method(os.rmdir)
+  rename = to_async_method(os.rename)
+  replace = to_async_method(os.replace)
 
   symlink = staticmethod(
-    method_as_method_coro(_NormalAccessor.symlink)
+    to_async_method(_NormalAccessor.symlink)
   )
 
-  utime = func_as_method_coro(os.utime)
-  readlink = method_as_method_coro(_NormalAccessor.readlink)
-  remove = coro_as_method_coro(async_os.remove)
+  utime = to_async_method(os.utime)
+  readlink = to_async_method(_NormalAccessor.readlink)
+  remove = to_async_method(os.remove)
 
   async def owner(self, path: str) -> str:
     try:
@@ -81,23 +79,25 @@ class _AsyncAccessor(_NormalAccessor):
     async for entry in scandir_async(*args, **kwargs):
       yield entry
 
-  expanduser = staticmethod(func_as_corofunc(os.path.expanduser))
+  expanduser = staticmethod(
+    func_to_async_func(os.path.expanduser)
+  )
 
 
 _async_accessor = _AsyncAccessor()
 
 
 class AsyncPurePath(PurePath):
-  def _init(self, template: Optional[PurePath] = None):
+  def _init(self, template: PurePath | None = None):
     self._accessor = _async_accessor
 
-  def __new__(cls, *args):
+  def __new__(cls: type, *args):
     if cls is AsyncPurePath:
-      cls = PureAsyncWindowsPath if os.name == 'nt' else PureAsyncPosixPath
+      cls = AsyncPureWindowsPath if os.name == 'nt' else AsyncPurePosixPath
     return cls._from_parts(args)
 
 
-class PureAsyncPosixPath(AsyncPurePath):
+class AsyncPurePosixPath(AsyncPurePath):
   """PurePath subclass for non-Windows systems.
   On a POSIX system, instantiating a PurePath should return this object.
   However, you can also instantiate it directly on any system.
@@ -106,7 +106,7 @@ class PureAsyncPosixPath(AsyncPurePath):
   __slots__ = ()
 
 
-class PureAsyncWindowsPath(AsyncPurePath):
+class AsyncPureWindowsPath(AsyncPurePath):
   """PurePath subclass for Windows systems.
   On a Windows system, instantiating a PurePath should return this object.
   However, you can also instantiate it directly on any system.
@@ -120,10 +120,10 @@ class AsyncPath(Path, AsyncPurePath):
     _async_windows_flavour if os.name == 'nt' else _async_posix_flavour
   _accessor = _async_accessor
 
-  def _init(self, template: Optional[AsyncPath] = None):
+  def _init(self, template: AsyncPath | None = None):
     self._accessor = _async_accessor
 
-  def __new__(cls, *args, **kwargs):
+  def __new__(cls: type, *args, **kwargs):
     if cls is AsyncPath:
       cls = AsyncWindowsPath if os.name == 'nt' else AsyncPosixPath
 
@@ -148,34 +148,26 @@ class AsyncPath(Path, AsyncPurePath):
     self,
     mode: FileMode = 'r',
     buffering: int = -1,
-    encoding: Optional[str] = DEFAULT_ENCODING,
-    errors: Optional[str] = ON_ERRORS,
-    newline: Optional[str] = NEWLINE,
-  ) -> IterableAIOFile:
-    return IterableAIOFile(
-      self._path,
+    encoding: str | None = DEFAULT_ENCODING,
+    errors: str | None = ON_ERRORS,
+    newline: str | None = NEWLINE,
+  ) -> Handle:
+    return get_handle(
+      str(self),
       mode,
-      encoding=encoding,
-      errors=errors,
-      newline=newline,
+      buffering,
+      encoding,
+      errors,
+      newline
     )
 
   async def read_text(
     self,
-    encoding: Optional[str] = DEFAULT_ENCODING,
-    errors: Optional[str] = ON_ERRORS
+    encoding: str | None = DEFAULT_ENCODING,
+    errors: str | None = ON_ERRORS
   ) -> str:
-
     async with self.open('r', encoding=encoding, errors=errors) as file:
-      return await file.read_text(encoding=encoding, errors=errors)
-
-    #path = str(await self.resolve())
-
-    #return await read_full_file(
-      #path,
-      #encoding=encoding,
-      #errors=errors
-    #)
+      return await file.read()
 
   async def read_bytes(self) -> bytes:
     async with self.open('rb') as file:
@@ -194,9 +186,9 @@ class AsyncPath(Path, AsyncPurePath):
   async def write_text(
     self,
     data: str,
-    encoding: Optional[str] = DEFAULT_ENCODING,
-    errors: Optional[str] = ON_ERRORS,
-    newline: Optional[str] = NEWLINE
+    encoding: str | None = DEFAULT_ENCODING,
+    errors: str | None = ON_ERRORS,
+    newline: str | None = NEWLINE
   ) -> int:
     """
     Open the file in text mode, write to it, and close the file.
@@ -315,7 +307,7 @@ class AsyncPath(Path, AsyncPurePath):
     """
     await self._accessor.link_to(self, target)
 
-  async def rename(self, target: Union[str, AsyncPath]) -> AsyncPath:
+  async def rename(self, target: str | AsyncPath) -> AsyncPath:
     """
     Rename this path to the target path.
     The target path may be absolute or relative. Relative paths are
@@ -363,25 +355,12 @@ class AsyncPath(Path, AsyncPurePath):
 
     return True
 
-  #async def exists(self) -> bool:
-    #try:
-      #async with async_open(self._path, 'rb'):
-        #pass
-
-      #return True
-
-    #except IsADirectoryError:
-      #return True
-
-    #except FileNotFoundError:
-      #return False
-
   @classmethod
-  async def cwd(cls: type) -> str:
+  def cwd(cls: type) -> AsyncPath:
     """Return a new path pointing to the current working directory
     (as returned by os.getcwd()).
     """
-    cwd: str = await getcwd()
+    cwd = getcwd()
     return cls(cwd)
 
   @classmethod
@@ -391,10 +370,16 @@ class AsyncPath(Path, AsyncPurePath):
     """
     return await cls('~').expanduser()
 
-  async def samefile(self, other_path: Union[AsyncPath, Path]) -> bool:
+  async def samefile(
+    self,
+    other_path: AsyncPath | Paths
+  ) -> bool:
     """Return whether other_path is the same or not as this file
     (as returned by os.path.samefile()).
     """
+    if isinstance(other_path, Paths):
+      other_path = AsyncPath(other_path)
+
     if isinstance(other_path, AsyncPath):
       try:
         other_st = await other_path.stat()
@@ -452,8 +437,8 @@ class AsyncPath(Path, AsyncPurePath):
     if drv or root:
       raise NotImplementedError("Non-relative patterns are unsupported")
 
-    #selector = _make_selector(("**",) + tuple(pattern_parts), self._flavour)
-    parts = ("**", *pattern_parts)
+    # selector = _make_selector(("**",) + tuple(pattern_parts), self._flavour)
+    parts: tuple[str, ...] = ("**", *pattern_parts)
     selector = _make_selector(parts, self._flavour)
 
     async for p in selector.select_from(self):
@@ -470,7 +455,8 @@ class AsyncPath(Path, AsyncPurePath):
         return self
     # FIXME this must defer to the specific flavour (and, under Windows,
     # use nt._getfullpathname())
-    obj = self._from_parts([await getcwd()] + self._parts, init=False)
+    parts: list[str] = [getcwd()] + self._parts
+    obj = self._from_parts(parts, init=False)
     obj._init(template=self)
     return obj
 
@@ -480,7 +466,7 @@ class AsyncPath(Path, AsyncPurePath):
     normalizing it (for example turning slashes into backslashes under
     Windows).
     """
-    s: Optional[str] = await self._flavour.resolve(self, strict=strict)
+    s: str | None = await self._flavour.resolve(self, strict=strict)
 
     if s is None:
       # No symlink resolution => for consistency, raise an error if
@@ -700,11 +686,11 @@ class AsyncPath(Path, AsyncPurePath):
       yield self._make_child_relpath(name)
 
 
-class AsyncPosixPath(PosixPath, AsyncPath, PureAsyncPosixPath):
+class AsyncPosixPath(PosixPath, AsyncPath, AsyncPurePosixPath):
   __slots__ = ()
 
 
-class AsyncWindowsPath(WindowsPath, AsyncPath, PureAsyncWindowsPath):
+class AsyncWindowsPath(WindowsPath, AsyncPath, AsyncPureWindowsPath):
   __slots__ = ()
 
   async def is_mount(self) -> int:
