@@ -1,16 +1,8 @@
-from typing import Callable, Awaitable, AsyncIterable, Iterable, \
-  Any, List
+from typing import AsyncIterable, Iterable, Any
 from os import scandir, DirEntry, stat_result
-from dataclasses import dataclass
 
 from .wrap import to_thread
 
-try:
-  from asyncio import to_thread
-
-except ImportError:
-  pass
-
 
 class EntryWrapper:
   __slots__ = "entry",
@@ -46,7 +38,7 @@ def wrapped_scandir(*args, **kwargs) -> Iterable[EntryWrapper]:
   yield from map(EntryWrapper, entries)
 
 
-def _scandir_results(*args, **kwargs) -> List[EntryWrapper]:
+def _scandir_results(*args, **kwargs) -> list[EntryWrapper]:
   return list(wrapped_scandir(*args, **kwargs))
 
 
